@@ -9,7 +9,7 @@ use Carp qw(croak);
 use XML::Simple; # because that's what Net::Fritz uses...
 use Net::Fritz::PhonebookEntry;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -298,7 +298,7 @@ sub reload( $self ) {
 
 =head1 SEE ALSO
 
-L<https://avm.de/fileadmin/user_upload/Global/Service/Schnittstellen/X_contactSCPD.pdf>
+L<https://avm.de/fileadmin/user_upload/Global/Service/Schnittstellen/x_contactSCPD.pdf>
 
 =cut
 
