@@ -5,7 +5,7 @@ use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 has entry => (
     is => 'ro',
@@ -43,7 +43,7 @@ sub build_structure( $self ) {
 
 =head1 SEE ALSO
 
-L<https://avm.de/fileadmin/user_upload/Global/Service/Schnittstellen/X_contactSCPD.pdf>
+L<https://avm.de/fileadmin/user_upload/Global/Service/Schnittstellen/x_contactSCPD.pdf>
 
 =cut
 
